<?
#This function is called whenever an error is encountered (e.g.
#cannot find a file or fail to access the database)
#The function optionally displays an error message in the browser
#and|or sends an email describing the error
#errortype = string to describe the error type (e.g. FILESYSTEM or DATABASE)
#linenumber = line number where the error occurred
#filename = name of file containing the error
#errordescription = additional description of the error
#Returns nothing
function HandleError($errortype, $linenumber, $filename, $errordescription) {

	#If ERROR_DISPLAY_ERROR_MESSAGES constant is set to true then
	#display error message in the browser
	if (ERROR_DISPLAY_ERROR_MESSAGES) {

		print "<b><font color=red>PHP ERROR</font></b><br>\n";
		print "<font color=blue>ERROR TYPE: </font>$errortype<br>\n";
		print "<font color=blue>FILEPATH: </font>" . $GLOBALS["PHP_SELF"] . "<br>\n";
		print "<font color=blue>LINENUMBER: </font>$linenumber<br>\n";
		print "<font color=blue>DESCRIPTION: </font>$errordescription<br>\n";

	}

	#If ERROR_SEND_ERROR_EMAILS constant is set to true then
	#send a description of the error
	if (ERROR_SEND_ERROR_EMAILS) {

		SendErrorEmail($errortype, $linenumber, $filename, $errordescription);

	}


}

/*This function sends an email describing a website error. The email
includes when and where the issue arose, together with the contents
of the HTTP Get, HTTP Post, and HTTP Server Variables arrays.
As such it can be used to alert a website administrator to
a potential issue with the site.
errortype = string to describe the error type (e.g. FILESYSTEM or DATABASE)
linenumber = line number where the error occurred
filename = name of file containing the error
errordescription = additional description of the error
Returns nothing*/
function SendErrorEmail($errortype, $linenumber, $filename, $errordescription) {

	global $HTTP_GET_VARS;
	global $HTTP_POST_VARS;
	global $HTTP_SERVER_VARS;

	$date_array = getdate();

	$day = $date_array[mday];
	$month = $date_array[mon];
	$year = $date_array[year];
	$hour = $date_array[hours];
	$minute = $date_array[minutes];
	$second = $date_array[seconds];

	$monthname = MonthName($month);

	if ($second < 10) {$second = "0$second";}
	if ($minute < 10) {$minute = "0$minute";}
	if ($hour < 10) {$hour = "0$hour";}

	#Prepare the contents of the email (which is sent in HTML format)
	$message = "

	<!DOCTYPE HTML PUBLIC\"-//IETF//DTD HTML//EN\">
	<html>
	<head>
	<title>". ERROR_MAIL_EMAIL_SUBJECT . "</title>
	</head>
	<body bgcolor=\"FFFFFF\">
	<p><font size =\"3\" face=\"Century Gothic, Arial\">
	<b>". ERROR_MAIL_EMAIL_SUBJECT . "</b><br>
	Error Report Generated: <FONT COLOR=\"#3333FF\">$day $monthname $year, $hour:$minute:$second</font><br>
	<hr>

	<b>Error Report:</b><br>
	Error Type: <FONT COLOR=\"#FF3333\">$errortype</FONT><BR>
	Error In Page: <FONT COLOR=\"#FF3333\">" . $GLOBALS["PHP_SELF"] . "</FONT><BR>
	Line Number: <FONT COLOR=\"#FF3333\">$linenumber</FONT><BR>
	Error Description: <FONT COLOR=\"#FF3333\">$errordescription</FONT><BR>
	<hr>
	<b>QueryString Collection:</b><br>
	";

	#If the HTTP_GET_VARS array is not empty then iterate
	#through the list of items in the array
	if (count($HTTP_GET_VARS) == 0) {

		$message .= "<FONT COLOR=\"#FF3333\">The QueryString array is empty</FONT><br>\n";

	} else {

		foreach ($HTTP_GET_VARS as $key=>$value) {

			$message .= "$key : <FONT COLOR=\"#3333FF\">$value</FONT><br>\n";

		}


	}

	$message .= "

	<hr>

	<b>Form Collection:</b><br>
	";

	#If the HTTP_POST_VARS array is not empty then iterate
	#through the list of items in the array
	if (count($HTTP_POST_VARS) == 0) {

		$message .= "<FONT COLOR=\"#FF3333\">The Form array is empty</FONT><br>\n";

	} else {

		foreach ($HTTP_POST_VARS as $key=>$value) {

			$message .= "$key : <FONT COLOR=\"#3333FF\">$value</FONT><br>\n";

		}


	}

	$message .= "

	<hr>

	<b>Server Variables:</b><br>
	";

	#If the HTTP_SERVER_VARS array is not empty then iterate
	#through the list of items in the array
	if (count($HTTP_SERVER_VARS) == 0) {

		$message .= "<FONT COLOR=\"#FF3333\">The Server Variables array is empty</FONT><br>\n";

	} else {

		foreach ($HTTP_SERVER_VARS as $key=>$value) {

			$message .= "$key : <FONT COLOR=\"#3333FF\">$value</FONT><br>\n";

		}


	}

	$message .= "

	</body>
	</html>

	";

	#Set the mail headers to send mail as HTML format
	$headers  = "MIME-Version: 1.0\r\n";
	$headers .= "Content-type: text/html; charset=iso-8859-1\r\n";

	#Send the email using PHP's integral mail facilities
	mail(ERROR_MAIL_EMAIL_ADDRESS, ERROR_MAIL_EMAIL_SUBJECT, $message, $headers);

}
?>